# Musicline

Music in a terminal.

MusicLine is a music player in the terminal. It is written in Python and uses [pygame](https://www.pygame.org/news) for playing music.
It is a simple and lightweight music player that can play music in the terminal. TUI uses Textual.
It is designed for command-line lovers who want to listen to music while working in the terminal.
It mix music with terminal vibes.

## Installation

### With `pip`

```shell
pip install musicline
```

### With Homebrew

Not avaliable yet.

### With a shell script

This script installs Python and MusicLine with Pip to simplify the installation.

The script is not ready yet.

## Help
When you open the app for the first time, you will be confused. Why? Because you're new to MusicLine. Press on **h** key on your keyboard when you are in the main menu to show Help menu.

Press **q** to quit the menu (not the app)

## Dependencies

Without these modules, this project wouldn't be a thing. Thanks to all of them (and their authors).

- [pygame](https://www.pygame.org/news): pygame is a set of Python modules designed for writing video games. It provides functionalities like sound, music, and graphics.
- [textual](https://textual.textualize.io/): Textual is a TUI (Text User Interface) framework for Python, allowing developers to create interactive terminal applications with rich user interfaces.
- [mutagen](https://mutagen.readthedocs.io/en/latest/): Mutagen is a Python module to handle audio metadata. It supports various formats, including MP3, FLAC, and Ogg Vorbis.
- [tomlkit](https://tomlkit.readthedocs.io/en/latest/): A Python library for parsing and creating TOML files, which are used for configuration.

## Contributing

If you want to contribute to this project, please fork the repository and create a pull request. All contributions are welcome.

Remember! You must act politely and respectfully. If you don't, you will be banned from the project.

If you're already banned and want to be unbanned, please contact the author of the project with email. Email is available in About menu in the app.
